import express from 'express';
import mongoose from 'mongoose';
import cors from 'cors';
import dotenv from 'dotenv';
dotenv.config();

import authRoutes from './routes/auth.js';
import tagRoutes  from './routes/tags.js';
import itemRoutes from './routes/items.js';
import authMiddleware from './middleware/auth.js';

const app  = express();
const PORT = process.env.PORT || 3000;

app.use(cors());
app.use(express.json());

app.use('/api/auth', authRoutes);

app.use('/api/tags', tagRoutes);
app.use('/api/items', itemRoutes);

mongoose
  .connect(process.env.MONGODB_URI!)
  .then(() => {
    app.listen(PORT, () => console.log(`✅ Server avviato su http://localhost:${PORT}`));
  })
  .catch(err => console.error('❌ Connessione MongoDB fallita:', err.message));
